# Examples

Jupyter notebooks demonstrating use cases.

* `conformer_energies/conformer_energies.ipynb`: Given a SMILES string, generate conformers and compute the single-point energy via GROMACS and OpenMM and compare to a result generated by the OpenFF toolkit.
* `ligand_in_water/ligand_in_water.ipynb`: Solvate a ligand in water and prepare a simulation.
* `packed_box/packed_box.ipynb`: Prepare a box of organic species for a simulation and compare the
  results of OpenMM, GROMACS, Amber, and LAMMPS.
* `protein_ligand/protein_ligand.ipynb`: Prepare a protein-ligand system for simulation using
  OpenFF tools and compare the results of OpenMM, GROMACS, Amber, and LAMMPS.
* `openmm/openmm.ipynb`: Prepare a box of organic species for a simulation with OpenMM.
* `lammps/lammps.ipynb`: Prepare a box of organic species for a simulation with LAMMPS.
* `vectorized_representations/vectorized_representations.ipynb`: Export systems to vectorized representations.
* `host_guest/host_guest.ipynb`: Prepare a host-guest system.
* `virtual_sites/virtual_sites.ipynb`: Apply several types of SMIRNOFF virtual sites to ligands.
